import { ShippingOption } from '@bigcommerce/checkout-sdk';
import React, { memo, useCallback, FunctionComponent } from 'react';

import { EMPTY_ARRAY } from '../../common/utility';
import { Checklist, ChecklistItem } from '../../ui/form';
import { LoadingOverlay } from '../../ui/loading';

import StaticShippingOption from './StaticShippingOption';

interface ShippingOptionListItemProps {
    consignmentId: string;
    shippingOption: ShippingOption;
}

const ShippingOptionListItem: FunctionComponent<ShippingOptionListItemProps> = ({
    consignmentId,
    shippingOption,
}) => {
    const renderLabel = useCallback(() => (
        <div className="shippingOptionLabel">
            <StaticShippingOption displayAdditionalInformation={ true } method={ shippingOption } />
        </div>
    ), [shippingOption]);

    return <ChecklistItem
        htmlId={ `shippingOptionRadio-${consignmentId}-${shippingOption.id}` }
        label={ renderLabel }
        value={ shippingOption.id }
        
    />;
};

export interface ShippingOptionListProps {
    consignmentId: string;
    inputName: string;
    isLoading: boolean;
    selectedShippingOptionId?: string;
    shippingOptions?: ShippingOption[];
    onSelectedOption(consignmentId: string, shippingOptionId: string): void;
}

const ShippingOptionsList: FunctionComponent<ShippingOptionListProps> = ({
    consignmentId,
    inputName,
    isLoading,
    shippingOptions = EMPTY_ARRAY,
    selectedShippingOptionId,
    onSelectedOption,
 }) => {
    const handleSelect = useCallback((value: string) => {
        onSelectedOption(consignmentId, value);
        // toggle show/hide extra customer comments
        // let shippingMethod = shippingOptions.find(option => option?.id == value)
        // const extraComments = document.querySelector("#shipping-extra-comments");
        // // if (shippingMethod?.type === "shipping_pickupinstore") {
        // if ( (shippingMethod?.type === "shipping_pickupinstore")||(shippingMethod?.type === "customerAccount") ) {
        //     extraComments?.setAttribute("style", "display:block");
        // } else {
        //     extraComments?.setAttribute("style", "display:none");
        // }
    }, [
        consignmentId,
        onSelectedOption,
    ]);

    if (!shippingOptions.length) {
        return null;
    }

    if (!isLoading) {
        let shippingMethod = shippingOptions.find(option => option?.id == selectedShippingOptionId)
        const extraComments = document.querySelector("#shipping-extra-comments");
        if ( (shippingMethod?.type === "shipping_pickupinstore") || (shippingMethod?.type === "customerAccount") ) {
            extraComments?.setAttribute("style", "display:block");
        } else {
            extraComments?.setAttribute("style", "display:none");
        }
    }

    const payYourOwnOption = shippingOptions.find(option => option?.type == "shipping_pickupinstore" || option?.type == "customerAccount")
    for (let i = 0; i < shippingOptions.length; i++) {
        if (shippingOptions[i]?.type == "shipping_pickupinstore" || shippingOptions[i]?.type == "customerAccount") {
            shippingOptions.splice(i, 1);
        }
    }
    if (payYourOwnOption) {
        shippingOptions.push(payYourOwnOption)
    }

    return (
        <LoadingOverlay isLoading={ isLoading }>
            <Checklist
                aria-live="polite"
                defaultSelectedItemId={ selectedShippingOptionId }
                name={ inputName }
                onSelect={ handleSelect }
            >
                { shippingOptions.map(shippingOption => (
                    <ShippingOptionListItem
                        consignmentId={ consignmentId }
                        key={ shippingOption.id }
                        shippingOption={ shippingOption }
                    />
                )) }
            </Checklist>
        </LoadingOverlay>
    );
};

export default memo(ShippingOptionsList);
